FFMPEG tools — MoviePy 1.0.1 documentation

# FFMPEG tools

Misc. bindings to ffmpeg and ImageMagick.

`moviepy.video.io.ffmpeg_tools.` `ffmpeg_extract_audio`(inputfile, output, bitrate=3000, fps=44100)

  extract the sound from a video file and save it in `output`

`moviepy.video.io.ffmpeg_tools.` `ffmpeg_extract_subclip`(filename, t1, t2, targetname=None)

  Makes a new video file playing video file `filename` between the times `t1` and `t2`.

`moviepy.video.io.ffmpeg_tools.` `ffmpeg_merge_video_audio`(video, audio, output, vcodec='copy', acodec='copy', ffmpeg_output=False, logger='bar')

  merges video file `video` and audio file `audio` into one movie file `output`.

`moviepy.video.io.ffmpeg_tools.` `ffmpeg_movie_from_frames`(filename, folder, fps, digits=6, bitrate='v')

  Writes a movie out of the frames (picture files) in a folder. Almost deprecated.

`moviepy.video.io.ffmpeg_tools.` `ffmpeg_resize`(video, output, size)

  resizes `video` to new size `size` and write the result in file `output`.